@@ -266,7 +266,7 @@ function webdeveloper_toggleCookies(element)
     var cookieBehavior = 0;
 
     // If disabling cookies
-    if(element.getAttribute("checked"))
+    if(webdeveloper_convertToBoolean(element.getAttribute("checked")))
     {
         cookieBehavior = 2;
     }
@@ -280,7 +280,7 @@ function webdeveloper_toggleExternalSiteCookies(element)
     var cookieBehavior = 0;
 
     // If disabling external cookies
-    if(element.getAttribute("checked"))
+    if(webdeveloper_convertToBoolean(element.getAttribute("checked")))
     {
         cookieBehavior = 1;
     }
