@@ -626,7 +626,7 @@ function webdeveloper_viewCSS()
             // If this is a valid style sheet
             if(webdeveloper_isValidStyleSheet(styleSheet.sheet) && (!styleSheet.hasAttribute("id") || styleSheet.getAttribute("id").indexOf("webdeveloper-") != 0))
             {
-                inlineStylesText += styleSheet.innerHTML.trim() + "\n\n";
+                inlineStylesText += webdeveloper_trim(styleSheet.innerHTML) + "\n\n";
             }
         }
 
