@@ -587,7 +587,7 @@ function webdeveloper_populateFormFields()
             if(!inputElement.disabled)
             {
                 // If the input element value is not set and the type is not set or is password or text
-                if(inputElement.value.trim() == "" && (!inputElementType || inputElementType == "password" || inputElementType == "text"))
+                if(webdeveloper_trim(inputElement.value) == "" && (!inputElementType || inputElementType == "password" || inputElementType == "text"))
                 {
                     inputElementName = inputElement.getAttribute("name");
 
@@ -618,7 +618,7 @@ function webdeveloper_populateFormFields()
             selectElement = selectElementList[j];
 
             // If the select element is not disabled and the value is not set
-            if(!selectElement.disabled && selectElement.value.trim() == "")
+            if(!selectElement.disabled && webdeveloper_trim(selectElement.value) == "")
             {
                 options       = selectElement.options;
                 optionsLength = options.length;
@@ -629,7 +629,7 @@ function webdeveloper_populateFormFields()
                     option = options.item(k);
 
                     // If the optionis set and the option text and option value are not empty
-                    if(option && option.text.trim() != "" && option.value.trim() != "")
+                    if(option && webdeveloper_trim(option.text) != "" && webdeveloper_trim(option.value) != "")
                     {
                         selectElement.selectedIndex = k;
 
@@ -645,7 +645,7 @@ function webdeveloper_populateFormFields()
             textAreaElement = textAreaElementList[j];
 
             // If the text area element is not disabled and the value is not set
-            if(!textAreaElement.disabled && textAreaElement.value.trim() == "")
+            if(!textAreaElement.disabled && webdeveloper_trim(textAreaElement.value) == "")
             {
                 textAreaElement.value = textAreaElement.getAttribute("name");
             }
