@@ -608,8 +608,8 @@ function webdeveloper_outlineImagesWithAdjustedDimensions(element)
             if(checked)
             {
                 // If the width or height has been adjusted
-                if((naturalWidth && imageElement.hasAttribute("width") && imageElement.getAttribute("width") != naturalWidth)
-                    || (naturalHeight && imageElement.hasAttribute("height") && imageElement.getAttribute("height") != naturalHeight))
+                if((naturalWidth && imageElement.width != naturalWidth)
+                || (naturalHeight && imageElement.height != naturalHeight))
                 {
                     imageElement.className += " webdeveloper-adjusted-image";
                 }
@@ -655,8 +655,8 @@ function webdeveloper_outlineImagesWithOversizedDimensions(element)
             if(checked)
             {
                 // If the width or height has been oversized
-                if((naturalWidth && imageElement.hasAttribute("width") && imageElement.getAttribute("width") > naturalWidth)
-                    || (naturalHeight && imageElement.hasAttribute("height") && imageElement.getAttribute("height") > naturalHeight))
+                if((naturalWidth && imageElement.width > naturalWidth)
+                || (naturalHeight && imageElement.height > naturalHeight))
                 {
                     imageElement.className += " webdeveloper-oversized-image";
                 }
