@@ -797,7 +797,7 @@ function webdeveloper_getTableHeadingText(headingNode, headingText)
         }
     }
 
-    return headingText.trim();
+    return webdeveloper_trim(headingText);
 }
 
 // Outputs the information for a table cell
@@ -1794,7 +1794,7 @@ function webdeveloper_viewDocumentOutline()
         {
             headerElement = headerElementList[j];
             headerTagName = headerElement.tagName.toLowerCase();
-            headerText    = webdeveloper_getElementText(headerElement).trim();
+            headerText    = webdeveloper_trim(webdeveloper_getElementText(headerElement));
             headerLevel   = parseInt(headerTagName.substring(1));
 
             // Loop through any missing headers
@@ -1820,7 +1820,7 @@ function webdeveloper_viewDocumentOutline()
 					headerText += headerImageList[k].getAttribute("alt") + " ";
 				}
            
-           		headerText = headerText.trim();
+           		headerText = webdeveloper_trim(headerText);
            
 				// If there is now header text
 				if(headerText)
