@@ -155,22 +155,32 @@ function webdeveloper_makeFramesResizable()
 // Shows all hidden elements
 function webdeveloper_showHiddenElements()
 {
-    var computedStyle   = null;
-    var display         = null;
-    var documentList    = webdeveloper_getDocuments(webdeveloper_getContentWindow());
-    var documentLength  = documentList.length;
-    var element         = null;
-    var hiddenElements  = new Array("area", "base", "basefont", "head", "meta", "param", "script", "style", "title");
-    var pageDocument    = null;
-    var tagName         = null;
-    var treeWalker      = null;
+    var computedStyle       = null;
+    var display             = null;
+    var documentList        = webdeveloper_getDocuments(webdeveloper_getContentWindow());
+    var documentLength      = documentList.length;
+    var element             = null;
+    var hiddenElements      = new Array("area", "base", "basefont", "head", "meta", "param", "script", "style", "title");
+    var inputElements       = null;
+    var inputElementsLength = null;
+    var pageDocument        = null;
+    var tagName             = null;
+    var treeWalker          = null;
 
     // Loop through the documents
     for(var i = 0; i < documentLength; i++)
     {
-        pageDocument = documentList[i];
-        treeWalker   = pageDocument.createTreeWalker(webdeveloper_getDocumentBodyElement(pageDocument), NodeFilter.SHOW_ELEMENT, null, false);
+        pageDocument        = documentList[i];
+        inputElements       = webdeveloper_evaluateXPath(pageDocument, "//input[@type='hidden']");
+        inputElementsLength = inputElements.length;
+        treeWalker          = pageDocument.createTreeWalker(webdeveloper_getDocumentBodyElement(pageDocument), NodeFilter.SHOW_ELEMENT, null, false);
 
+        // Loop through all the input tags
+        for(var j = 0; j < inputElementsLength; j++)
+        {
+            inputElements[j].setAttribute("type", "text");
+				}
+				
         // While the tree walker has more nodes
         while((element = treeWalker.nextNode()) != null)
         {
