@@ -22,7 +22,7 @@ function webdeveloper_outlineBlockLevelElements(element)
 // Outlines the current element
 function webdeveloper_outlineCurrentElement(element)
 {
-    var checked        = element.getAttribute("checked");
+    var checked        = webdeveloper_convertToBoolean(element.getAttribute("checked"));
     var documentList   = webdeveloper_getDocuments(webdeveloper_getContentWindow());
     var documentLength = documentList.length;
     var pageDocument   = null;
@@ -116,7 +116,7 @@ function webdeveloper_outlineCustomElements(element)
     webdeveloper_outlinedElements = new Array();
 
     // If the menu is checked
-    if(element.getAttribute("checked"))
+    if(webdeveloper_convertToBoolean(element.getAttribute("checked")))
     {
         window.openDialog("chrome://webdeveloper/content/dialogs/outline_elements.xul", "webdeveloper-outline-elements-dialog", "centerscreen,chrome,modal", webdeveloper_outlinedElements);
 
@@ -155,7 +155,7 @@ function webdeveloper_outlineDeprecatedElements(element)
 function webdeveloper_outlineElements(element)
 {
     // If the menu is checked
-    if(element.getAttribute("checked") && webdeveloper_outlinedElements.length > 0)
+    if(webdeveloper_convertToBoolean(element.getAttribute("checked")) && webdeveloper_outlinedElements.length > 0)
     {
         var documentList             = webdeveloper_getDocuments(webdeveloper_getContentWindow());
         var documentLength           = documentList.length;
@@ -226,7 +226,7 @@ function webdeveloper_outlineElements(element)
 function webdeveloper_outlineExternalLinks(element)
 {
     // If the menu is checked
-    if(element.getAttribute("checked"))
+    if(webdeveloper_convertToBoolean(element.getAttribute("checked")))
     {
         var documentList   = webdeveloper_getDocuments(webdeveloper_getContentWindow());
         var documentLength = documentList.length;
@@ -262,7 +262,7 @@ function webdeveloper_outlineExternalLinks(element)
 // Outlines all floated elements
 function webdeveloper_outlineFloatedElements(element)
 {
-    var checked        = element.getAttribute("checked");
+    var checked        = webdeveloper_convertToBoolean(element.getAttribute("checked"));
     var className      = null;
     var documentList   = webdeveloper_getDocuments(webdeveloper_getContentWindow());
     var documentLength = documentList.length;
@@ -350,7 +350,7 @@ function webdeveloper_outlineLinksWithoutTitleAttributes(element)
 function webdeveloper_outlinePositionedElements(position, element)
 {
     var attributeName  = "webdeveloper-" + position + "-positioned-element";
-    var checked        = element.getAttribute("checked");
+    var checked        = webdeveloper_convertToBoolean(element.getAttribute("checked"));
     var className      = null;
     var documentList   = webdeveloper_getDocuments(webdeveloper_getContentWindow());
     var documentLength = documentList.length;
