@@ -1563,7 +1563,7 @@ function webdeveloper_tidyImages(imageList)
         imageSrc = image.src;
 
         // If the image src is set and does not end in '.xul'
-        if(imageSrc && !imageSrc.endsWith(".xul"))
+        if(imageSrc && !webdeveloper_endsWith(imageSrc, ".xul"))
         {
             newImageList.push(image);
         }
@@ -1898,7 +1898,7 @@ function webdeveloper_updateJavaScriptStatus(error)
                 }
             }
         }
-        else if(!javaScriptButton.hasAttribute("class") || javaScriptButton.getAttribute("class") != "valid")
+        else if(!javaScriptButton.hasAttribute("class") || (javaScriptButton.getAttribute("class") != "disabled" && javaScriptButton.getAttribute("class") != "valid"))
         {
             javaScriptButton.setAttribute("class", "valid");
             javaScriptButton.setAttribute("tooltiptext", stringBundle.getString("webdeveloper_javaScriptNoErrorsTooltip"));
